``` bash
sudo apt update -y 
sudo apt-get update
sudo apt-get dist-upgrade 
```
``` bash
sudo apt-get install pipenv
```
``` bash
pipenv --python 3.7 && pipenv shell
```
``` bash
pip install aea[all]
```
